@@ -49,6 +49,7 @@ import os
 import urllib.request
 import warnings
 from datetime import datetime, timedelta
+import sys
 
 import cfgrib
 import pandas as pd
@@ -82,12 +83,12 @@ def _searchString_help(kind="wgrib2"):
 
     Parameters
     ----------
-    kind : {"wgrib2", "grib_ls"}
+    kind : {"wgrib2", "eccodes"}
         There are two different utilities used to create index files and
         they create different file output.
 
         - **wgrib2** is the NCEP-style grib messages
-        - **grib_ls** is the ECMWF-style grib messages
+        - **eccodes** is the ECMWF-style grib messages
     """
 
     if kind == "wgrib2":
@@ -108,6 +109,8 @@ Here are some examples you can use for the wgrib2-style `searchString`
     ":UGRD:10 m"                  U wind component at 10 meters.
     ":(U|V)GRD:(10|80) m"         U and V wind component at 10 and 80 m.
     ":(U|V)GRD:"                  U and V wind component at all levels.
+    ":(?:U|V)GRD:[0-9]+ hybrid"   U and V wind components at all hybrid levels
+    ":(?:U|V)GRD:[0-9]+ mb"        U and V wind components at all pressure levels
     ":.GRD:"                      (Same as above)
     ":(TMP|DPT):"                 Temperature and Dew Point for all levels .
     ":(TMP|DPT|RH):"              TMP, DPT, and Relative Humidity for all levels.
@@ -119,10 +122,10 @@ If you need help with regular expression, search the web or look at
 this cheatsheet: https://www.petefreitag.com/cheatsheets/regex/.
 """
 
-    elif kind == "grib_ls":
+    elif kind == "eccodes":
         msg = """
 Use regular expression to search for lines in the index file.
-Here are some examples you can use for the grib_ls-style `searchString`
+Here are some examples you can use for the ecCodes-style `searchString`
 
 Look at the ECMWF GRIB Parameter Database
 https://apps.ecmwf.int/codes/grib/param-db
@@ -184,12 +187,13 @@ class Herbie:
         Forecast lead time in hours. Available lead times depend on
         the model type and model version. Range is model and run
         dependant.
-    model : {'hrrr', 'hrrrak', 'rap', 'gfs', 'gfs_wave', 'rrfs', etc.}
+    model : {'hrrr', 'hrrrak', 'rap', 'gfs', 'gfs_wave', 'ecmwf', 'rrfs', etc.}
         Model name as defined in the models template folder. CASE INSENSITIVE
         Some examples:
         - ``'hrrr'`` HRRR contiguous United States model
         - ``'hrrrak'`` HRRR Alaska model (alias ``'alaska'``)
         - ``'rap'`` RAP model
+        - ``'ecmwf'`` ECMWF open data forecat products
     product : {'sfc', 'prs', 'nat', 'subh'}
         Output variable product file type. If not specified, will
         use first product in model template file. CASE SENSITIVE.
@@ -221,6 +225,7 @@ class Herbie:
     **kwargs
         Any other paremeter needed to satisfy the conditions in the
         model template file (e.g., nest=2, other_label='run2')
+
     """
 
     def __init__(
@@ -264,6 +269,7 @@ class Herbie:
             # TODO: Check if the kwarg is a config default.
             # TODO: e.g. if a user primarily works with RRFS, they may
             # TODO: want to configure "member" as a default argument.
+            # You may also set IDX_SUFFIX as an argument.
             setattr(self, key, value)
 
         # Get details from the template of the specified model.
@@ -291,7 +297,7 @@ class Herbie:
 
         # Specify the index file type. By default, Herbie assumes the
         # index file was created with wgrib2.
-        # But for ecmwf files with index files created with grib_ls
+        # But for ecmwf files with index files created with eccodes
         # the index files are in a different style.
         self.IDX_STYLE = getattr(self, "IDX_STYLE", "wgrib2")
         self.searchString_help = _searchString_help(self.IDX_STYLE)
@@ -422,6 +428,9 @@ class Herbie:
         assert self.model in _models, f"`model` must be one of {_models}"
         assert self.product in _products, f"`product` must be one of {_products}"
 
+        if isinstance(self.IDX_SUFFIX, str):
+            self.IDX_SUFFIX = [self.IDX_SUFFIX]
+
         if isinstance(self.priority, str):
             self.priority = [self.priority]
 
@@ -459,15 +468,18 @@ class Herbie:
         """Check if an index file exist for the GRIB2 URL."""
         # To check inventory files with slightly different URL structure
         # we will loop through the IDX_SUFFIX.
-        if not isinstance(self.IDX_SUFFIX, list):
-            self.IDX_SUFFIX = [self.IDX_SUFFIX]
 
         if verbose:
             print(f"🐜 {self.IDX_SUFFIX=}")
 
         # Loop through IDX_SUFFIX options until we find one that exists
         for i in self.IDX_SUFFIX:
-            idx_url = url.rsplit(".", maxsplit=1)[0] + i
+
+            if Path(url).suffix in {".grb", ".grib", ".grb2", ".grib2"}:
+                idx_url = url.rsplit(".", maxsplit=1)[0] + i
+            else:
+                idx_url = url + i
+
             idx_exists = requests.head(idx_url).ok
             if verbose:
                 print(f"🐜 {idx_url=}")
@@ -539,7 +551,7 @@ class Herbie:
             Execute ``_searchString_help()`` for examples of a good
             searchString.
 
-            .. include:: ../user_guide/searchString.rst
+            .. include:: ../../user_guide/searchString.rst
 
         Returns
         -------
@@ -619,8 +631,8 @@ class Herbie:
                 )
             )
 
-        if self.IDX_STYLE == "grib_ls":
-            # grib_ls keywords explained here:
+        if self.IDX_STYLE == "eccodes":
+            # eccodes keywords explained here:
             # https://confluence.ecmwf.int/display/UDOC/Identification+keywords
 
             r = requests.get(self.idx)
@@ -712,7 +724,7 @@ class Herbie:
         searchString : str
             If None, download the full file. Else, use regex to subset
             the file by specific variables and levels.
-            .. include:: ../user_guide/searchString.rst
+            .. include:: ../../user_guide/searchString.rst
         source : {'nomads', 'aws', 'google', 'azure', 'pando', 'pando2'}
             If None, download GRIB2 file from self.grib2 which is
             the first location the GRIB2 file was found from the
@@ -750,7 +762,16 @@ class Herbie:
             )
 
         def subset(searchString, outFile):
-            """Download a subset specified by the regex searchString"""
+            """
+            Download a subset specified by the regex searchString
+            """
+            # TODO An alternative to downloadling subset with curl is
+            # TODO  to use the request module directly.
+            # TODO  >> headers = dict(Range=f"bytes={start_bytes}-{end_bytes}")
+            # TODO  >> r = requests.get(grib_url, headers=headers)
+            # TODO  Except does this allow multiple ranges??
+            # TODO  See example here: https://github.com/pangeo-forge/pangeo-forge-recipes/issues/267#issuecomment-1026934765
+
             grib_source = self.grib
             if hasattr(grib_source, "as_posix") and grib_source.exists():
                 # The GRIB source is local. Curl the local file
@@ -886,14 +907,14 @@ class Herbie:
         # Use cfgrib.open_datasets, just in case there are multiple "hypercubes"
         # for what we requested.
         Hxr = cfgrib.open_datasets(
-            self.get_localFilePath(searchString=searchString),
+            local_file,
             backend_kwargs=backend_kwargs,
         )
 
         # Get CF grid projection information with pygrib and pyproj because
         # this is something cfgrib doesn't do (https://github.com/ecmwf/cfgrib/issues/251)
         # NOTE: Assumes the projection is the same for all variables
-        grib = pygrib.open(str(self.get_localFilePath(searchString=searchString)))
+        grib = pygrib.open(str(local_file))
         msg = grib.message(1)
         cf_params = CRS(msg.projparams).to_cf()
 
@@ -912,7 +933,8 @@ class Herbie:
             ds.attrs["product"] = self.product
             ds.attrs["description"] = self.DESCRIPTION
             ds.attrs["remote_grib"] = self.grib
-            ds.attrs["local_grib"] = self.get_localFilePath(searchString=searchString)
+            ds.attrs["local_grib"] = local_file
+            ds.attrs["searchString"] = searchString
 
             # Attach CF grid mapping
             # ----------------------
@@ -930,21 +952,28 @@ class Herbie:
                 ds[var].attrs["grid_mapping"] = "gribfile_projection"
 
         if remove_grib:
-            # Only remove grib if it didn't exists before
-
-            # Load the data to memory before removing the file
+            # Load the datasets into memory before removing the file
             Hxr = [ds.load() for ds in Hxr]
-            # new = Hxr.copy()
+            _ = [ds.close() for ds in Hxr]
 
-            # Close the files so it can be removed (this issue seems
-            # to be WindowsOS specific).
-            # for ds in Hxr:
-            #    ds.close()
-
-            # Removes file
-            local_file.unlink()
-
-            # Hxr = new
+            # TODO:
+            # Forcefully close the files so it can be removed
+            # (this is a WindowsOS specific requirement).
+            # os.close(?WHAT IS THE FILE HANDLER?)
+            """
+            https://docs.python.org/3/library/os.html#os.remove
+            On Windows, attempting to remove a file that is in use
+            causes an exception to be raised; on Unix, the directory
+            entry is removed but the storage allocated to the file is
+            not made available until the original file is no longer in
+            use.
+            >> HOW DO I COMPLETELY CLOSE THE FILE OPENED BY CFGRIB??
+            """
+            if not sys.platform == "win32":
+                # Removes file
+                local_file.unlink()
+            else:
+                warnings.warn("sorry, on windows I couldn't remove the file.")
 
         if len(Hxr) == 1:
             return Hxr[0]
